Two-mode networks can be represented (or 'projected') as one-mode networks.
Usage
minmax_overlap(A, row =TRUE, min =TRUE)
Arguments
A
A matrix object
row
Whether to consider the actors in the rows of the matrix (default) or the column.
min
Whether to extract the minimum (default) or the maximum overlap.
Value
This function return the overlap between the modes (a.k.a. actors, nodes, vertices).
References
Morris, S.A. (2005). Unified Mathematical Treatment of Complex Cascaded Bipartite Networks: The Case of Collections of Journal Papers. Unpublished PhD Thesis, Oklahoma State University.